import { Link } from "wouter";
import { Logo } from "@/components/ui/Logo";
import { Button } from "@/components/ui/button";
import { useState } from "react";

export default function Header() {
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  return (
    <header className="bg-black shadow-md">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center py-4">
          <Link href="/">
            <div className="flex items-center cursor-pointer">
              <Logo size={42} className="text-white" />
              <h1 className="ml-3 text-2xl font-bold text-white">
                CoinLabe
              </h1>
            </div>
          </Link>
          <nav className="hidden md:flex space-x-8">
            <Link href="/" className="text-white hover:text-gray-300 font-medium transition duration-150">
              Home
            </Link>
            <a href="https://blog.coinlabe.com/about-us/" className="text-gray-300 hover:text-white font-medium transition duration-150">
              About Us
            </a>
            <a href="https://blog.coinlabe.com/privacy-policy/" className="text-gray-300 hover:text-white font-medium transition duration-150">
              Privacy Policy
            </a>
            <a href="https://blog.coinlabe.com" className="text-gray-300 hover:text-white font-medium transition duration-150">
              Blog
            </a>
            <a href="https://blog.coinlabe.com/contact" className="text-gray-300 hover:text-white font-medium transition duration-150">
              Contact
            </a>
          </nav>
          
          {/* Mobile Menu Button */}
          <div className="md:hidden">
            <button 
              onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
              className="text-white hover:text-gray-300 focus:outline-none"
            >
              {isMobileMenuOpen ? (
                <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                </svg>
              ) : (
                <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M4 6h16M4 12h16m-7 6h7" />
                </svg>
              )}
            </button>
          </div>
        </div>
        
        {/* Mobile Menu */}
        {isMobileMenuOpen && (
          <div className="md:hidden">
            <div className="px-2 pt-2 pb-3 space-y-1 sm:px-3 bg-gray-900">
              <Link 
                href="/" 
                className="text-white hover:text-gray-300 block px-3 py-2 font-medium transition duration-150"
                onClick={() => setIsMobileMenuOpen(false)}
              >
                Home
              </Link>
              <a 
                href="https://blog.coinlabe.com/about-us/" 
                className="text-gray-300 hover:text-white block px-3 py-2 font-medium transition duration-150"
                onClick={() => setIsMobileMenuOpen(false)}
              >
                About Us
              </a>
              <a 
                href="https://blog.coinlabe.com/privacy-policy/" 
                className="text-gray-300 hover:text-white block px-3 py-2 font-medium transition duration-150"
                onClick={() => setIsMobileMenuOpen(false)}
              >
                Privacy Policy
              </a>
              <a 
                href="https://blog.coinlabe.com" 
                className="text-gray-300 hover:text-white block px-3 py-2 font-medium transition duration-150"
                onClick={() => setIsMobileMenuOpen(false)}
              >
                Blog
              </a>
              <a 
                href="https://blog.coinlabe.com/contact" 
                className="text-gray-300 hover:text-white block px-3 py-2 font-medium transition duration-150"
                onClick={() => setIsMobileMenuOpen(false)}
              >
                Contact
              </a>
            </div>
          </div>
        )}
      </div>
    </header>
  );
}
